@@ -4,7 +4,7 @@
  *
  *  Copyright (C) 2000-2001  Qualcomm Incorporated
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2009  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2010  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -429,7 +429,7 @@ char *bt_compidtostr(int compid)
 	case 70:
 		return "MediaTek, Inc.";
 	case 71:
-		return "Bluegiga";	/* (tentative) */
+		return "Bluegiga";
 	case 72:
 		return "Marvell Technology Group Ltd.";
 	case 73:
